@@ -7,7 +7,7 @@ from __future__ import annotations
 import logging
 import struct
 from collections.abc import Iterator
-from typing import Any, Union
+from typing import Any
 
 import pefile
 from abi3info.models import PyVersion, Symbol, Visibility
@@ -59,8 +59,7 @@ class _SharedObjectBase:
             )
             return assume_lowest
 
-        # With no wheel tags and no filename tag, fall back on the assumed ABI
-        # version (which is possibly None).
+        # With no wheel tags and no filename tag, fall back on the assumed ABI version.
         return assume_lowest
 
     def __str__(self) -> str:
@@ -135,7 +134,7 @@ class _Dylib(_SharedObjectBase):
         try:
             with mach_o.MachO.from_file(self._extractor.path) as macho:
                 yield macho
-        except Exception:
+        except Exception as exc:
             logger.debug(f"mach-o decode for {self._extractor.path} failed; trying as a fat mach-o")
             # To handle "fat" Mach-Os, we do some ad-hoc parsing below:
             # * Check that we're really in a fat Mach-O and, if
@@ -155,7 +154,7 @@ class _Dylib(_SharedObjectBase):
                     # Mach-O Fat headers, but they never appear in the wild.
                     raise SharedObjectError(
                         f"bad magic: {hex(magic)} (not FAT_MAGIC or FAT_MAGIC_64)"
-                    )
+                    ) from exc
 
                 (nfat_arch,) = struct.unpack(fieldspec[0], io.read(fieldspec[1]))
                 for _ in range(nfat_arch):
@@ -244,4 +243,4 @@ class _Dll(_SharedObjectBase):
                     yield Symbol(imp.name.decode(), visibility="global")
 
 
-SharedObject = Union[_So, _Dll, _Dylib]
+SharedObject = _So | _Dll | _Dylib
